==> v2.29.0.241129.zip: qairt/2.29.0.241129/lib/python/qti/aisw/tools/core/utilities/devices/android/android_device_constants.py <==
# ==============================================================================
#
# Copyright (c) Qualcomm Technologies, Inc.
# All Rights Reserved.
# Confidential and Proprietary - Qualcomm Technologies, Inc.
#
# ==============================================================================

""" Contains constants specific to android device manager """

SOC_ID_TO_SOC_NAME = {
    # Mobile Devices
    "371": "SXR1130",
    "336": "SDM670",
    "349": "SDM632",
    "338": "SDM450",
    "339": "SM8150",
    "360": "SDM710",
    "353": "SDM439",
    "481": "QCS8250",
    "365": "SM7150",
    "366": "SM7150",
    "394": "SM6125",
    "345": "SDM636",
    "317": "SDM660",
    "352": "QCS405",
    "400": "SM7250",
    "347": "QCS605",
    "407": "SM6250",
    "417": "SM4250",
    "420": "SM4250P",
    "443": "SM7125",
    "444": "SM6115",
    "445": "SM6115P",
    "415": "SM8350",
    "457": "SM8450",
    "434": "SM6350",
    "459": "SM7225",
    "441": "SM4125",
    "318": "SDM630",
    "401": "QCS610_LE",
    "406": "QCS410",
    "475": "SM7325",
    "454": "SM4350",
    "450": "SM7350",
    "411": "QCS405",
    "356": "SM8250",
    "476": "Fraser_SM7250",
    "455": "QRB5165",
    "410": "QCS404",
    "355": "SM6150",
    "467": "QCM6125",
    "501": "SM8325",
    "469": "QCM4290",
    "470": "QCS4290",
    "497": "QCM6490",
    "498": "QCS6490",
    "507": "SM6375",
    "506": "SM7450",
    "530": "SM8475",
    "519": "SM8550",
    "564": "SM7425",
    "591": "SM7475",
    "537": "SM6450",
    "482": "SM8450",
    "536": "SM8550",
    "568": "SM4450",
    "557": "SM8650",
    "618": "SM8750",
    # XR Devices
    "525": "SXR1230P",  # Aurora/Neo
    "549": "SXR2230P",  # Halliday
    "554": "SSG2115P",  # Aurora LA / Luna
    "579": "SSG2125P",  # Luna V2
    "649": "SXR2250P",  # XR2Gen2+ or Halliday+
}

# Interval time in seconds
POLL_DEVICES_INTERVAL = 5
UNKNOWN_SOC_NAME = "UNKNOWN"

==> v2.39.0.250926.zip: qairt/2.39.0.250926/lib/python/qti/aisw/tools/core/utilities/devices/android/android_device_constants.py <==
# ==============================================================================
#
# Copyright (c) Qualcomm Technologies, Inc.
# All Rights Reserved.
# Confidential and Proprietary - Qualcomm Technologies, Inc.
#
# ==============================================================================

"""Contains constants specific to android device manager"""

SOC_ID_TO_SOC_NAME = {
    # Mobile Devices
    "371": "SXR1130",
    "336": "SDM670",
    "349": "SDM632",
    "338": "SDM450",
    "339": "SM8150",
    "360": "SDM710",
    "353": "SDM439",
    "481": "QCS8250",
    "365": "SM7150",
    "366": "SM7150",
    "394": "SM6125",
    "345": "SDM636",
    "317": "SDM660",
    "352": "QCS405",
    "400": "SM7250",
    "347": "QCS605",
    "407": "SM6250",
    "417": "SM4250",
    "420": "SM4250",
    "443": "SM7125",
    "444": "SM6115",
    "445": "SM6115",
    "415": "SM8350",
    "457": "SM8450",
    "434": "SM6350",
    "459": "SM7225",
    "441": "SM4125",
    "318": "SDM630",
    "401": "QCS610_LE",
    "406": "QCS410",
    "475": "SM7325",
    "454": "SM4350",
    "450": "SM7350",
    "411": "QCS405",
    "356": "SM8250",
    "476": "Fraser_SM7250",
    "455": "QRB5165",
    "410": "QCS404",
    "355": "SM6150",
    "467": "QCM6125",
    "501": "SM8325",
    "469": "QCM4290",
    "470": "QCS4290",
    "497": "QCM6490",
    "498": "QCS6490",
    "507": "SM6375",
    "506": "SM7450",
    "530": "SM8475",
    "519": "SM8550",
    "564": "SM7425",
    "591": "SM7475",
    "537": "SM6450",
    "482": "SM8450",
    "536": "SM8550",
    "600": "SM8550",
    "601": "SM8550",
    "568": "SM4450",
    "557": "SM8650",
    "577": "SM8650",
    "618": "SM8750",
    "639": "SM8750",
    "696": "SM8650",
    "538": "SC8380XP",
    "435": "SC8280X",
    "439": "SM8350",
    "548": "QCS7230",
    "518": "SM6225",
    "523": "QRB4210",
    "581": "QCM4490",
    "515": "SM7315",
    "608": "SM7550",
    "644": "SM7550",
    "687": "SM7550",
    "614": "SM8635",
    "632": "SM7675",
    "603": "QCS8550",
    "604": "QCS8550",  # QCM8550
    "667": "QCS9100",
    "676": "QCS9100",
    "657": "QCM6690",
    "658": "QCS6690",
    "668": "QCS8550",
    "674": "QCS8300",
    "675": "QCS8300",
    "688": "QCS8550",
    "473": "QCM2290",
    "474": "QCS2290",
    # XR Devices
    "525": "SXR1230P",  # Aurora/Neo
    "549": "SXR2230P",  # Halliday
    "554": "SSG2115P",  # Aurora LA / Luna
    "579": "SSG2125P",  # Luna V2
    "649": "SXR2250P",  # XR2Gen2+ or Halliday+
}

# Interval time in seconds
POLL_DEVICES_INTERVAL = 5
UNKNOWN_SOC_NAME = "UNKNOWN"
